@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 
 # This is used as a diagnostic to send to the module author
 
@@ -6,22 +6,28 @@ use strict;
 
 use Data::Dumper;
 use Graphics::Framebuffer;
-$Data::Dumper::Sortkeys = 1;
-my $dev = 0;
-$dev = $ARGV[0] if (scalar(@ARGV));
+
+$Data::Dumper::Sortkeys = 1; $Data::Dumper::Purity = 1;
+
+my $dev = $ARGV[0] || 0;
+
 print "Using /dev/fb$dev\n";
 sleep 1;
 if (open(my $FILE, '>', 'dump.log')) {
     eval {
-        my ($fb, $f) = Graphics::Framebuffer->new('SHOW_ERRORS' => 1, 'FB_DEVICE' => "/dev/fb$dev");
-        $fb->cls();
+        my ($fb, $f) = Graphics::Framebuffer->new('SHOW_ERRORS' => 0, 'FB_DEVICE' => "/dev/fb$dev", 'RESET' => 0);
 
         my $copy = $fb;
 
         delete($copy->{'SCREEN'});
+        delete($copy->{'ACCEL_TYPES'});
         foreach my $name (sort(keys %{$copy})) {
-            unless (ref($copy->{$name}) =~ /Imager|threads|GLOB|ARRAY|HASH|SUB/i) {
-                print FILE "$name = " . $copy->{$name} . "\n";
+            if ($name =~ /^(FBI|VT)/i) {
+                delete($copy->{$name});
+            } else {
+                unless (ref($copy->{$name}) =~ /Imager|threads|GLOB|ARRAY|HASH|SUB/i) {
+                    print FILE "$name = " . $copy->{$name} . "\n";
+                }
             }
         }
         print $FILE '=' x 79 . "\n";
@@ -46,6 +52,6 @@ It creates a file called B<dump.log> in the same directory.  Please send this fi
 
 =head1 SYNOPSIS
 
- perl dump.pl [frambuffer_number]
+ perl dump.pl [frambuffer_number, if needed]
 
 =cut
